@@ -92,20 +92,10 @@ def version_from_news(srcdir):
                     version = [j] + n.split('.')
 
                 if release[0] < 0:
-                    try:
-                        dateinfo = info.split('(')[1].split(')')[0].split()
-                        num_count = 0
-                        for d in dateinfo:
-                            try:
-                                if int(d) > 0:
-                                    num_count += 1
-                            except Exception:
-                                pass
-                        if num_count > 1:
+                    s = ''.join(c for c in info if c.isdigit())
+                    if len(s) > 0:
                             release = [j] + n.split('.')
                             break
-                    except Exception:
-                        pass
 
     if trunk > -1:
         if version[0] > -1:
@@ -245,7 +235,8 @@ def svn_version(srcdir, defaults):
     cmd = ['svn', 'info', '--xml', srcdir]
     p = subprocess.Popen(cmd,
                          stdout=subprocess.PIPE,
-                         stderr=subprocess.PIPE)
+                         stderr=subprocess.PIPE,
+                         universal_newlines=True)
     output = p.communicate()
     if p.returncode != 0:
         return major, minor, release, extra, revision
@@ -277,7 +268,8 @@ def svn_version(srcdir, defaults):
 
         p = subprocess.Popen(cmd,
                              stdout=subprocess.PIPE,
-                             stderr=subprocess.PIPE)
+                             stderr=subprocess.PIPE,
+                             universal_newlines=True)
         output = p.communicate()
         if p.returncode != 0:
             return major, minor, release, extra, revision
@@ -335,7 +327,8 @@ def svn_version_is_modified(srcdir):
 
     p = subprocess.Popen(['svn', 'status', '--xml', srcdir],
                          stdout=subprocess.PIPE,
-                         stderr=subprocess.PIPE)
+                         stderr=subprocess.PIPE,
+                         universal_newlines=True)
     output = p.communicate()
 
     if p.returncode == 0:
@@ -405,12 +398,18 @@ def git_version(srcdir, defaults):
     url = None
     revision = ''
     head_is_svn = False
+    newline_failed = False
 
     cmd = ['git', '--no-pager', '--git-dir='+os.path.join(srcdir, '.git'),
            '--work-tree='+srcdir, 'log', '-n', '200']
+
+    # Universal newlines options may fail in some cases with
+    # Python 3, so check for newlines using '\n' and '\\n' later.
+
     p = subprocess.Popen(cmd,
                          stdout=subprocess.PIPE,
-                         stderr=subprocess.PIPE)
+                         stderr=subprocess.PIPE,
+                         universal_newlines=False)
     output = p.communicate()
     if p.returncode != 0:
         return major, minor, release, extra
@@ -432,6 +431,7 @@ def git_version(srcdir, defaults):
     if not head_is_svn:
         commit_id = o0.find('commit')
         commit_rev = o0[commit_id:].split(' ', 2)[1].split('\n')[0]
+        commit_rev = commit_rev.split('\\n')[0] # newline detection robustness
         revision += '-git' + commit_rev
 
     return major, minor, release, extra, revision
@@ -450,7 +450,8 @@ def git_version_is_modified(srcdir):
            '--work-tree='+srcdir, 'status', '-s', '-uno']
     p = subprocess.Popen(cmd,
                          stdout=subprocess.PIPE,
-                         stderr=subprocess.PIPE)
+                         stderr=subprocess.PIPE,
+                         universal_newlines=True)
     output = p.communicate()
     o0 = str(output[0])
     if p.returncode == 0:
