@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2015 EDF S.A.
+# Copyright (C) 1998-2016 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -681,7 +681,6 @@ Calculation management
             self.setRowClose(self.tr('Boundary conditions'))
             self.setRowClose(self.tr('Numerical parameters'))
             self.setRowClose(self.tr('Start/Restart'))
-            self.setRowClose(self.tr('Performance tuning'))
             self.setRowClose(self.tr('Time averages'))
             self.setRowClose(self.tr('Volume solution control'))
             self.setRowClose(self.tr('Surface solution control'))
@@ -696,7 +695,6 @@ Calculation management
             self.setRowOpen(self.tr('Boundary conditions'))
             self.setRowOpen(self.tr('Numerical parameters'))
             self.setRowOpen(self.tr('Start/Restart'))
-            self.setRowOpen(self.tr('Performance tuning'))
             self.setRowOpen(self.tr('Time averages'))
             self.setRowOpen(self.tr('Volume solution control'))
             self.setRowOpen(self.tr('Surface solution control'))
