@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2015 EDF S.A.
+# Copyright (C) 1998-2016 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -779,7 +779,7 @@ class BatchRunningView(QWidget, Ui_BatchRunningForm):
         if rm_type == None:
             run_id, run_title = self.__suggest_run_id()
             self.__updateRuncase(run_id)
-            cmd = batch
+            cmd = cs_exec_environment.enquote_arg(batch)
         else:
             run_title = self.case['package'].code_name + ' - Job Submission'
             cmd = cs_exec_environment.enquote_arg(sys.argv[0]) \
