@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2015 EDF S.A.
+# Copyright (C) 1998-2016 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -156,7 +156,7 @@ class OutputControlModel(Model):
         default['directory']                 = 'postprocessing'
 
         if self.case['salome']:
-            default['format'] = "MED"
+            default['format'] = "med"
 
         return default
 
