@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2015 EDF S.A.
+# Copyright (C) 1998-2016 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -239,8 +239,11 @@ class TurbulenceModel(Variables, Model):
             self.setWallFunction(wall_function)
 
         elif model_turb in self.LESmodels():
-            self.setNewProperty(self.node_turb, 'smagorinsky_constant^2')
-            self.__removeVariablesAndProperties([], 'turbulent_viscosity')
+            if model_turb == 'LES_dynamique':
+                self.setNewProperty(self.node_turb, 'smagorinsky_constant^2')
+            else:
+                self.__removeVariablesAndProperties([], 'smagorinsky_constant^2')
+            self.setNewProperty(self.node_turb, 'turbulent_viscosity')
             self.node_turb.xmlRemoveChild('wall_function')
 
             from code_saturne.Pages.TimeStepModel import TimeStepModel
