@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2015 EDF S.A.
+# Copyright (C) 1998-2016 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -190,7 +190,7 @@ class TurbulenceView(QWidget, Ui_TurbulenceForm):
         self.modelTurbModel.addItem(self.tr("Mixing length"), "mixing_length")
         self.modelTurbModel.addItem(self.tr("k-epsilon"), "k-epsilon")
         self.modelTurbModel.addItem(self.tr("k-epsilon Linear Production"), "k-epsilon-PL")
-        self.modelTurbModel.addItem(self.tr("Rij-epsilon LLR"), "Rij-epsilon")
+        self.modelTurbModel.addItem(self.tr("Rij-epsilon LRR"), "Rij-epsilon")
         self.modelTurbModel.addItem(self.tr("Rij-epsilon SSG"), "Rij-SSG")
         self.modelTurbModel.addItem(self.tr("Rij-epsilon EBRSM"), "Rij-EBRSM")
         self.modelTurbModel.addItem(self.tr("v2f BL-v2/k"), "v2f-BL-v2/k")
