@@ -5,7 +5,7 @@
 /*
   This file is part of Code_Saturne, a general-purpose CFD tool.
 
-  Copyright (C) 1998-2015 EDF S.A.
+  Copyright (C) 1998-2016 EDF S.A.
 
   This program is free software; you can redistribute it and/or modify it under
   the terms of the GNU General Public License as published by the Free Software
@@ -74,44 +74,22 @@ BEGIN_C_DECLS
 /*! (DOXYGEN_SHOULD_SKIP_THIS) \endcond */
 
 /*============================================================================
- *  Public function definitions for Fortran API
+ * Public function definitions
  *============================================================================*/
 
-/* Return the dot product of 2 vectors: x.y */
-
-double CS_PROCF(csdot, CSDOT)(const cs_int_t   *n,
-                              const cs_real_t  *x,
-                              const cs_real_t  *y)
-{
-  return cs_dot(*n, x, y);
-}
-
-/* Return the global residual of 2 extensiv vectors: x.y */
-
-double CS_PROCF(csres, CSRES)(const cs_int_t   *n,
-                              const cs_real_t  *vol,
-                              const cs_real_t  *x,
-                              const cs_real_t  *y)
-{
-  return cs_gres(*n, vol, x, y);
-}
-
-/*============================================================================
- *  Public function definitions
- *============================================================================*/
-
-/*----------------------------------------------------------------------------
- * Constant times a vector plus a vector: y <-- ax + y
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief Constant times a vector plus a vector: y <-- ax + y
  *
- * parameters:
- *   n <-- size of arrays x and y
- *   a <-- multiplier for x
- *   x <-- array of floating-point values
- *   y <-- array of floating-point values
- *----------------------------------------------------------------------------*/
+ * \param[in]       n  size of arrays x and y
+ * \param[in]       a  multiplier for x
+ * \param[in]       x  array of floating-point values
+ * \param[in, out]  y  array of floating-point values
+ */
+/*----------------------------------------------------------------------------*/
 
-void cs_axpy(cs_lnum_t      n,
-             double         a,
+void cs_axpy(cs_lnum_t         n,
+             double            a,
              const cs_real_t  *x,
              cs_real_t        *restrict y)
 {
@@ -125,19 +103,17 @@ void cs_axpy(cs_lnum_t      n,
     y[i] += (a * x[i]);
 }
 
-/*----------------------------------------------------------------------------
- * Return the dot product of 2 vectors: x.y
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief Return the dot product of 2 vectors: x.y
  *
- * For better precision, a superblock algorithm is used.
+ * \param[in]  n  size of arrays x and y
+ * \param[in]  x  array of floating-point values
+ * \param[in]  y  array of floating-point values
  *
- * parameters:
- *   n <-- size of arrays x and y
- *   x <-- array of floating-point values
- *   y <-- array of floating-point values
- *
- * returns:
- *   dot product
- *----------------------------------------------------------------------------*/
+ * \return  dot product
+ */
+/*----------------------------------------------------------------------------*/
 
 double
 cs_dot(cs_lnum_t         n,
@@ -188,21 +164,22 @@ cs_dot(cs_lnum_t         n,
   return dot;
 }
 
-/*----------------------------------------------------------------------------
- * Return the global residual of 2 extensive vectors:
- *  1/sum(vol) . sum(X.Y/vol)
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief Return the global residual of 2 extensive vectors:
+ *        1/sum(vol) . sum(X.Y/vol)
  *
- * For better precision, a superblock algorithm is used.
+ * In parallel mode, the local results are summed on the default
+ * global communicator.
  *
- * parameters:
- *   n   <-- size of arrays x and y
- *   vol <-- array of floating-point values
- *   x   <-- array of floating-point values
- *   y   <-- array of floating-point values
+ * \param[in]  n    size of arrays x and y
+ * \param[in]  vol  array of floating-point values
+ * \param[in]  x    array of floating-point values
+ * \param[in]  y    array of floating-point values
  *
- * returns:
- *   global residual
- *----------------------------------------------------------------------------*/
+ * \return  global residual
+ */
+/*----------------------------------------------------------------------------*/
 
 double
 cs_gres(cs_lnum_t         n,
@@ -270,18 +247,18 @@ cs_gres(cs_lnum_t         n,
   return dot;
 }
 
-/*----------------------------------------------------------------------------
- * Return dot products of a vector with itself: x.x
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief Return dot products of a vector with itself: x.x
  *
  * For better precision, a superblock algorithm is used.
  *
- * parameters:
- *   n  <-- size of arrays x and y
- *   x  <-- array of floating-point values
+ * \param[in]  n  size of array x
+ * \param[in]  x  array of floating-point values
  *
- * returns:
- *   dot product
- *----------------------------------------------------------------------------*/
+ * \return  dot product
+ */
+/*----------------------------------------------------------------------------*/
 
 double
 cs_dot_xx(cs_lnum_t         n,
@@ -323,8 +300,9 @@ cs_dot_xx(cs_lnum_t         n,
   return dot_xx;
 }
 
-/*----------------------------------------------------------------------------
- * Return 2 dot products of 2 vectors: x.x, and x.y
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief Return 2 dot products of 2 vectors: x.x, and x.y
  *
  * The products could be computed separately, but computing them
  * simultaneously adds more optimization opportunities and possibly better
@@ -332,13 +310,13 @@ cs_dot_xx(cs_lnum_t         n,
  *
  * For better precision, a superblock algorithm is used.
  *
- * parameters:
- *   n  <-- size of arrays x and y
- *   x  <-- array of floating-point values
- *   y  <-- array of floating-point values
- *   xx --> x.x dot product
- *   xy --> x.y dot product
- *----------------------------------------------------------------------------*/
+ * \param[in]   n   size of arrays x and y
+ * \param[in]   x   array of floating-point values
+ * \param[in]   y   array of floating-point values
+ * \param[out]  xx  x.x dot product
+ * \param[out]  xy  x.y dot product
+ */
+/*----------------------------------------------------------------------------*/
 
 void
 cs_dot_xx_xy(cs_lnum_t                    n,
@@ -399,8 +377,9 @@ cs_dot_xx_xy(cs_lnum_t                    n,
   *xy = dot_xy;
 }
 
-/*----------------------------------------------------------------------------
- * Return 2 dot products of 3 vectors: x.y, and y.z
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief Return 2 dot products of 3 vectors: x.x, and y.z
  *
  * The products could be computed separately, but computing them
  * simultaneously adds more optimization opportunities and possibly better
@@ -408,14 +387,14 @@ cs_dot_xx_xy(cs_lnum_t                    n,
  *
  * For better precision, a superblock algorithm is used.
  *
- * parameters:
- *   n  <-- size of arrays x and y
- *   x  <-- array of floating-point values
- *   y  <-- array of floating-point values
- *   z  <-- array of floating-point values
- *   xy --> x.y dot product
- *   yz --> y.z dot product
- *----------------------------------------------------------------------------*/
+ * \param[in]   n   size of arrays x and y, and z
+ * \param[in]   x   array of floating-point values
+ * \param[in]   y   array of floating-point values
+ * \param[in]   z   array of floating-point values
+ * \param[out]  xy  x.y dot product
+ * \param[out]  yz  y.z dot product
+ */
+/*----------------------------------------------------------------------------*/
 
 void
 cs_dot_xy_yz(cs_lnum_t                    n,
@@ -477,8 +456,9 @@ cs_dot_xy_yz(cs_lnum_t                    n,
   *yz = dot_yz;
 }
 
-/*----------------------------------------------------------------------------
- * Return 3 dot products of 3 vectors: x.y, x.y, and y.z
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief Return 3 dot products of 3 vectors: x.x, x.y, and y.z
  *
  * The products could be computed separately, but computing them
  * simultaneously adds more optimization opportunities and possibly better
@@ -486,15 +466,15 @@ cs_dot_xy_yz(cs_lnum_t                    n,
  *
  * For better precision, a superblock algorithm is used.
  *
- * parameters:
- *   n  <-- size of arrays x and y
- *   x  <-- array of floating-point values
- *   y  <-- array of floating-point values
- *   z  <-- array of floating-point values
- *   xx --> x.y dot product
- *   xy --> x.y dot product
- *   yz --> y.z dot product
- *----------------------------------------------------------------------------*/
+ * \param[in]   n   size of arrays x and y, and z
+ * \param[in]   x   array of floating-point values
+ * \param[in]   y   array of floating-point values
+ * \param[in]   z   array of floating-point values
+ * \param[out]  xx  x.x dot product
+ * \param[out]  xy  x.y dot product
+ * \param[out]  yz  y.z dot product
+ */
+/*----------------------------------------------------------------------------*/
 
 void
 cs_dot_xx_xy_yz(cs_lnum_t                    n,
@@ -567,8 +547,9 @@ cs_dot_xx_xy_yz(cs_lnum_t                    n,
   *yz = dot_yz;
 }
 
-/*----------------------------------------------------------------------------
- * Return 5 dot products of 3 vectors: x.x, y.y, x.y, x.z, and y.z
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief Return 5 dot products of 3 vectors: x.x, y.y, x.y, x.z, and y.z
  *
  * The products could be computed separately, but computing them
  * simultaneously adds more optimization opportunities and possibly better
@@ -576,17 +557,17 @@ cs_dot_xx_xy_yz(cs_lnum_t                    n,
  *
  * For better precision, a superblock algorithm is used.
  *
- * parameters:
- *   n  <-- size of arrays x and y
- *   x  <-- array of floating-point values
- *   y  <-- array of floating-point values
- *   z  <-- array of floating-point values
- *   xx --> x.y dot product
- *   yy --> y.y dot product
- *   xy --> x.y dot product
- *   xz --> x.z dot product
- *   yz --> y.z dot product
- *----------------------------------------------------------------------------*/
+ * \param[in]   n   size of arrays x and y, and z
+ * \param[in]   x   array of floating-point values
+ * \param[in]   y   array of floating-point values
+ * \param[in]   z   array of floating-point values
+ * \param[out]  xx  x.x dot product
+ * \param[out]  yy  y.y dot product
+ * \param[out]  xy  x.y dot product
+ * \param[out]  xz  x.z dot product
+ * \param[out]  yz  y.z dot product
+ */
+/*----------------------------------------------------------------------------*/
 
 void
 cs_dot_xx_yy_xy_xz_yz(cs_lnum_t                    n,
@@ -678,22 +659,22 @@ cs_dot_xx_yy_xy_xz_yz(cs_lnum_t                    n,
   *yz = dot_yz;
 }
 
-/*----------------------------------------------------------------------------
- * Return the global dot product of 2 vectors: x.y
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief Return the global dot product of 2 vectors: x.y
  *
  * In parallel mode, the local results are summed on the default
  * global communicator.
  *
  * For better precision, a superblock algorithm is used.
  *
- * parameters:
- *   n <-- size of arrays x and y
- *   x <-- array of floating-point values
- *   y <-- array of floating-point values
+ * \param[in]  n  size of arrays x and y
+ * \param[in]  x  array of floating-point values
+ * \param[in]  y  array of floating-point values
  *
- * returns:
- *   dot product
- *----------------------------------------------------------------------------*/
+ * \return  dot product
+ */
+/*----------------------------------------------------------------------------*/
 
 double
 cs_gdot(cs_lnum_t         n,
