@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2015 EDF S.A.
+! Copyright (C) 1998-2016 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -594,44 +594,6 @@ if (isuite.eq.1) then
 
   endif
 
-  ! Using unsteady rotor/stator, geometric parameters must be recalculated
-  if (iturbo.eq.2) then
-
-    ! Update mesh
-
-    call turbomachinery_update_mesh(ttpmob, rvoid(1))
-
-    ! Update arrays whose size could have changed (nfac, ncelet)
-
-    ! Main internal faces properties array
-    call turbomachinery_reinit_i_face_fields
-
-    if (irangp.ge.0 .or. iperio.eq.1) then
-
-      ! Main and auxiliary arrays
-      call resize_aux_arrays
-      call resize_main_real_array ( dt , propce )
-
-      ! Turbo module
-      call turbomachinery_update
-
-      ! Fields
-      call fldtri(nproce, dt, propce)
-
-      ! Other arrays, depending on user options
-      if (iilagr.gt.0) &
-           call resize_n_sca_real_arrays ( ntersl, tslagr )
-
-      if (iphydr.eq.1) then
-        call resize_vec_real_array_ni ( frcxt )
-      elseif (iphydr.eq.2) then
-        call resize_sca_real_array ( prhyd )
-      endif
-
-    endif
-
-  endif
-
   call timer_stats_stop(restart_stats_id)
 
 endif
@@ -1042,6 +1004,10 @@ if (iisuit.eq.1) then
 
   call ecrava(frcxt, prhyd)
 
+  if (iturbo.eq.2 .and. iecaux.eq.1) then
+    call trbsui
+  endif
+
   if (nfpt1t.gt.0) then
     ficsui = '1dwall_module'
     call ecrt1d                                                   &
@@ -1054,7 +1020,7 @@ if (iisuit.eq.1) then
   endif
 
   if (ippmod(iaeros).ge.0) then
-     call ecrctw ('cooling_towers'//c_null_char)
+    call ecrctw ('cooling_towers'//c_null_char)
   endif
 
   if (iilagr.gt.0) then
