@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2015 EDF S.A.
+! Copyright (C) 1998-2016 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -146,7 +146,7 @@ if (numtyp .eq. -1) then
 
   ! Wall distance (if LES+VanDriest or Rij+Echo or K-w SST)
 
-  if (ineedy.eq.1 .and. abs(icdpar).eq.1) then
+  if (ineedy.eq.1) then
 
     idimt = 1
     ientla = .true.
@@ -159,7 +159,7 @@ if (numtyp .eq. -1) then
 
   ! Yplus (if LES+VanDriest)
 
-  if (ineedy.eq.1 .and. abs(icdpar).eq.1) then
+  if (ineedy.eq.1) then
 
     if (itytur.eq.4.and.idries.eq.1) then
 
@@ -517,34 +517,6 @@ else if (numtyp .eq. -2) then
 
   endif
 
-  ! Temperature at the boundary
-  ! ---------------------------
-
-  if (ipstdv(ipsttb).ne.0) then
-
-    idimt = 1        ! variable dimension
-    ientla = .true.  ! interleaved values
-    ivarpr = .false. ! defined on work array
-
-    ! Compute variable on boundary faces
-
-    call post_boundary_temperature(nfbrps, lstfbr, trafbr)
-
-    if (itherm .eq. 1) then
-      name80 = 'Boundary temperature'
-    else if (itherm .eq. 2) then
-      name80 = 'Boundary enthalpy'
-    else if (itherm .eq. 3) then
-      name80 = 'Boundary energy'
-    else
-      return
-    endif
-
-    call post_write_var(nummai, name80, idimt, ientla, ivarpr,  &
-                        ntcabs, ttcabs, rbid, rbid, trafbr)
-
-  endif ! end of test on output of wall temperature
-
   ! Nusselt at the boundary
   ! -----------------------
 
