@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2015 EDF S.A.
+! Copyright (C) 1998-2016 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -727,6 +727,11 @@ if (iturbo.eq.2 .and. iterns.eq.1) then
 
     if (idtten.ge.0) call field_get_val_v(idtten, dttens)
 
+    if (icavit.ge.0) then
+      call field_get_val_s(ivarfl(ivoidf), cvar_voidf)
+      call field_get_val_prev_s(ivarfl(ivoidf), cvara_voidf)
+    endif
+
   endif
 
   ! Update the Dirichlet wall boundary conditions for velocity (based on the
@@ -1114,7 +1119,7 @@ if (imobil.eq.1 .or. iturbo.eq.1 .or. iturbo.eq.2) then
 
   if (iturbo.eq.1.or.iturbo.eq.2) call dmtmps(t3)
 
-  !$omp parallel do private(iel1, iel2, dtfac, rhofac)
+  !$omp parallel do private(iel1, iel2, rhofac)
   do ifac = 1, nfac
     iel1 = ifacel(1,ifac)
     iel2 = ifacel(2,ifac)
@@ -1130,7 +1135,7 @@ if (imobil.eq.1 .or. iturbo.eq.1 .or. iturbo.eq.2) then
                         + surfac(3,ifac)*(vr1(3) + vr2(3)) )
     endif
   enddo
-  !$omp parallel do private(iel, dtfac, rhofac) if(nfabor > thr_n_min)
+  !$omp parallel do private(iel, rhofac) if(nfabor > thr_n_min)
   do ifac = 1, nfabor
     iel = ifabor(ifac)
     if (irotce(iel).ne.0) then
@@ -1190,7 +1195,7 @@ if (icavit.ge.0) then
     call field_get_val_prev_s(icrom, croma)
 
     call cavitation_print_mass_budget &
-   ( crom, croma, dt, imasfl, bmasfl )
+   ( crom, croma, brom, dt, imasfl, bmasfl )
 
   endif
 
