@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2015 EDF S.A.
+! Copyright (C) 1998-2016 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -449,6 +449,20 @@ if (idfm.eq.1 .or. itytur.eq.3 .and. idirsm.eq.1) then
           enddo
         enddo
 
+        ! No damping with Durbing scale for the scalar
+        if (iggafm.eq.1) then
+          call field_get_val_v(ivstes, vistes)
+
+          do iel = 1, ncel
+            trrij = 0.5d0*(cvar_r11(iel)+cvar_r22(iel)+cvar_r33(iel))
+            rottke  = csrij * crom(iel) * trrij / cvar_ep(iel)
+
+            do isou = 1, 6
+              visten(isou, iel) = rottke*cvar_rij(isou, iel)
+            enddo
+          enddo
+        endif
+
       ! LRR or SSG
       else
         do iel = 1, ncel
@@ -460,6 +474,8 @@ if (idfm.eq.1 .or. itytur.eq.3 .and. idirsm.eq.1) then
           enddo
         enddo
       endif
+
+    ! Uncoupled version
     else
       call field_get_val_s(icrom, crom)
       call field_get_val_s(iprpfl(iviscl), viscl)
@@ -491,6 +507,23 @@ if (idfm.eq.1 .or. itytur.eq.3 .and. idirsm.eq.1) then
           visten(6,iel) = rottke*cvar_r13(iel)
         enddo
 
+        if (iggafm.eq.1) then
+          call field_get_val_v(ivstes, vistes)
+
+          do iel = 1, ncel
+            trrij = 0.5d0*(cvar_r11(iel)+cvar_r22(iel)+cvar_r33(iel))
+            rottke  = csrij * crom(iel) * trrij / cvar_ep(iel)
+
+            vistes(1,iel) = rottke*cvar_r11(iel)
+            vistes(2,iel) = rottke*cvar_r22(iel)
+            vistes(3,iel) = rottke*cvar_r33(iel)
+            vistes(4,iel) = rottke*cvar_r12(iel)
+            vistes(5,iel) = rottke*cvar_r23(iel)
+            vistes(6,iel) = rottke*cvar_r13(iel)
+          enddo
+        endif
+
+
       ! LRR or SSG
       else
         do iel = 1, ncel
