@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2015 EDF S.A.
+! Copyright (C) 1998-2016 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -91,6 +91,7 @@ use cs_tagmr, only: rob, condb, cpb, hext, text
 use cs_tagms, only: t_metal, tmet0
 use cs_nz_tagmr
 use cs_nz_condensation
+use turbomachinery
 
 ! les " use pp* " ne servent que pour recuperer le pointeur IIZFPP
 
@@ -1408,6 +1409,12 @@ do while (iterns.le.nterup)
         frcxt  , prhyd  ,                                              &
         trava  , ximpav , uvwk   )
 
+      ! Update local pointer arrays for transient turbomachinery computations
+      if (iturbo.eq.2) then
+        call field_get_val_s(ivarfl(ipr), cvar_pr)
+        call field_get_val_prev_s(ivarfl(ipr), cvara_pr)
+      endif
+
     else
 
       call richards (icvrge, dt)
