@@ -6,7 +6,7 @@
 /*
   This file is part of Code_Saturne, a general-purpose CFD tool.
 
-  Copyright (C) 1998-2015 EDF S.A.
+  Copyright (C) 1998-2016 EDF S.A.
 
   This program is free software; you can redistribute it and/or modify it under
   the terms of the GNU General Public License as published by the Free Software
@@ -566,7 +566,7 @@ _export_vertex_coords(const fvm_nodal_t        *mesh,
     vtkIdTypeArray *g_vtx_id = vtkIdTypeArray::New();
 
     g_vtx_id->SetNumberOfComponents(1);
-    g_vtx_id->SetName("GlobalNodeId");
+    g_vtx_id->SetName("GlobalNodeIds");
     g_vtx_id->SetNumberOfTuples(n_vertices);
 
     for (i = 0; i < n_vertices; i++) {
