@@ -5,7 +5,7 @@
 /*
   This file is part of Code_Saturne, a general-purpose CFD tool.
 
-  Copyright (C) 1998-2015 EDF S.A.
+  Copyright (C) 1998-2016 EDF S.A.
 
   This program is free software; you can redistribute it and/or modify it under
   the terms of the GNU General Public License as published by the Free Software
@@ -517,184 +517,6 @@ _close_plugin(fvm_writer_format_t  *wf)
  * Semi-private function definitions (prototypes in fvm_writer_priv.h)
  *============================================================================*/
 
-/*----------------------------------------------------------------------------
- * Compute recommended buffer sizes to input or output a nodal mesh
- * definition by slices. This is especially useful when gathering the mesh for
- * output by slices using standard I/O in parallel mode.
- *
- * The global number of vertices and elements of each slice may also
- * be returned, if the pointers n_g_vertices and n_g_elements_section
- * are non-NULL respectively.
- *
- * The number of slices indicated is a minimum, and only a target;
- * computation is based primarily on cell and face connectivity, and the
- * target should be met for strided connectivities on those types of elements
- * only. Using an "optimistic" (i.e. small) mean number of vertices per
- * polyhedra or polygon will typically lead to requiring more slices, as
- * the connectivity slice size returned will be smaller than that truly
- * required for the corresponding slice size.
- * Slice sizes required for edges connectivity will meet the target only
- * when the global numbers of cells and faces given are zero, so as to
- * avoid generating too large connectivity slice sizes for cells should a mesh
- * contain both (as for example a hexahedral connectivity slice is 8 times
- * larger than the corresponding slice size, while an edges connectivity is
- * only 2 times as large).
- *
- * parameters:
- *   this_nodal                 <-- pointer to nodal mesh structure
- *   n_slices                   <-- target number of slices required
- *   n_polyhedron_vertices_mean <-- estimate of the mean number of vertices
- *                                  per polyhedron
- *   n_polygon_vertices_mean    <-- estimate of the mean number of vertices
- *                                  per polygon
- *   n_g_vertices               --> global number of vertices (or NULL)
- *   n_g_elements_section       --> array for global number of elements per
- *                                  section (or NULL)
- *   global_s_size              --> maximum number of entities defined per slice
- *   global_connect_s_size      --> maximum number of connectivity values
- *                                  per slice
- *----------------------------------------------------------------------------*/
-
-void
-fvm_writer_def_nodal_buf_size(const fvm_nodal_t  *this_nodal,
-                              int                 n_slices,
-                              int                 n_polyhedron_vertices_mean,
-                              int                 n_polygon_vertices_mean,
-                              cs_gnum_t          *n_g_vertices,
-                              cs_gnum_t           n_g_elements_section[],
-                              cs_gnum_t          *global_s_size,
-                              cs_gnum_t          *global_connect_s_size)
-{
-  int  i;
-  cs_gnum_t   n_g_elements = 0;
-  cs_gnum_t   n_g_cells = 0, n_g_faces = 0, n_g_edges = 0;
-  cs_gnum_t   _n_g_vertices = 0;
-
-  cs_gnum_t   connect_size = 0;
-  cs_gnum_t   *_n_g_elements_section = NULL;
-
-  const fvm_nodal_section_t  *section = NULL;
-
-  assert(this_nodal != NULL);
-
-  if (n_g_elements_section == NULL)
-    BFT_MALLOC(_n_g_elements_section, this_nodal->n_sections, cs_gnum_t);
-  else
-    _n_g_elements_section = n_g_elements_section;
-
-  /* Vertices */
-
-  if (this_nodal->global_vertex_num != NULL)
-    _n_g_vertices = fvm_io_num_get_global_count(this_nodal->global_vertex_num);
-  else
-    _n_g_vertices = this_nodal->n_vertices;
-
-  if (n_g_vertices != NULL)
-    *n_g_vertices = _n_g_vertices;
-
-  /* Edges, faces, and cells */
-
-  for (i = 0; i < this_nodal->n_sections; i++) {
-
-    section = this_nodal->sections[i];
-
-    n_g_elements = fvm_nodal_section_n_g_elements(section);
-
-    switch(section->entity_dim) {
-    case 1:
-      n_g_edges += n_g_elements;
-      break;
-    case 2:
-      n_g_faces += n_g_elements;
-      break;
-    default:
-      n_g_cells += n_g_elements;
-    }
-
-    _n_g_elements_section[i] = n_g_elements;
-
-  }
-
-  /* Define global slice size as (global_size / n_ranks) +  1 */
-
-  *global_s_size = CS_MAX(n_g_cells, n_g_faces);
-
-  if (*global_s_size == 0)
-    *global_s_size = n_g_edges;
-
-  if (*global_s_size == 0) /* Should the mesh contain only vertices */
-    *global_s_size = _n_g_vertices;
-
-  *global_s_size = (*global_s_size / n_slices) + 1;
-
-  /* Now compute best size for connectivity buffer,
-     using estimated "mean" numbers of nodes per polyhedron and per polygon */
-
-  *global_connect_s_size = 0;
-
-  for (i = 0; i < this_nodal->n_sections; i++) {
-
-    section = this_nodal->sections[i];
-
-    switch(section->type) {
-    case FVM_FACE_POLY:
-    case FVM_CELL_POLY:
-      if (section->type == FVM_FACE_POLY)
-        connect_size =   CS_MIN(_n_g_elements_section[i], *global_s_size)
-                       * n_polygon_vertices_mean;
-      else if (section->type == FVM_CELL_POLY)
-        connect_size =   CS_MIN(_n_g_elements_section[i], *global_s_size)
-                       * n_polyhedron_vertices_mean;
-
-      if (section->tesselation != NULL) {
-
-        int  i_type;
-
-        const fvm_tesselation_t  *tesselation = section->tesselation;
-        const int  n_sub_types = fvm_tesselation_n_sub_types(tesselation);
-
-        for (i_type = 0; i_type < n_sub_types; i_type++) {
-
-          int  stride;
-          cs_lnum_t   n_sub_elements_max;
-
-          fvm_element_t  sub_type = fvm_tesselation_sub_type(tesselation,
-                                                             i_type);
-
-          fvm_tesselation_get_global_size(tesselation,
-                                          sub_type,
-                                          NULL,
-                                          &n_sub_elements_max);
-
-          stride = fvm_nodal_n_vertices_element[sub_type];
-
-
-          connect_size = CS_MAX(connect_size,
-                                (cs_gnum_t)n_sub_elements_max * stride);
-
-        }
-
-      }
-
-      break;
-      break;
-    default:
-      connect_size =   CS_MIN(_n_g_elements_section[i], *global_s_size)
-                     * section->stride;
-    }
-
-    /* Buffer size is that required for the entity type
-       requiring the largest buffer size */
-
-    *global_connect_s_size = CS_MAX(*global_connect_s_size,
-                                    connect_size);
-
-  }
-
-  if (n_g_elements_section != _n_g_elements_section)
-    BFT_FREE(_n_g_elements_section);
-}
-
 /*! (DOXYGEN_SHOULD_SKIP_THIS) \endcond */
 
 /*============================================================================
